@@ -180,7 +180,7 @@ class AirTouch:
         #should this turn the group on?
 
     def GetAcs(self):
-        acs = [AirTouchAc];
+        acs = [];
         for acNumber in self.acs.keys(): 
             ac = self.acs[acNumber]
             acs.append(ac);
